# CLI Reference

Command-line tools for OneTool.

| CLI | Description |
|-----|-------------|
| [**onetool**](onetool.md) | Start the OneTool MCP server |
| [**bench**](bench.md) | Benchmark agent + MCP server combinations |
